==> alt-ergo_0.91.orig.tar.gz: alt-ergo-0.91/why_typing.mli <==
(**************************************************************************)
(*                                                                        *)
(*     The Alt-ergo theorem prover                                        *)
(*     Copyright (C) 2006-2010                                            *)
(*                                                                        *)
(*     Sylvain Conchon                                                    *)
(*     Evelyne Contejean                                                  *)
(*     Stephane Lescuyer                                                  *)
(*     Mohamed Iguernelala                                                *)
(*     Alain Mebsout                                                      *)
(*                                                                        *)
(*     CNRS - INRIA - Universite Paris Sud                                *)
(*                                                                        *)
(*   This file is distributed under the terms of the CeCILL-C licence     *)
(*                                                                        *)
(**************************************************************************)

type error 

exception Error of error * Why_ptree.loc

(*
type tdecl = 
  | Assume of Formula.t * Why_ptree.loc * bool
  | PredDef of Formula.t * Why_ptree.loc
  | Query of string * Formula.t * Literal.t list * Why_ptree.loc
*)
val make_cnf : (Why_ptree.typed_decl * bool) list -> Why_ptree.sat_tdecl Queue.t

val file : Why_ptree.file -> Why_ptree.typed_decl list list

val report : Format.formatter -> error -> unit

==> alt-ergo_0.93.orig.tar.gz: alt-ergo-0.93/why_typing.mli <==
(**************************************************************************)
(*                                                                        *)
(*     The Alt-ergo theorem prover                                        *)
(*     Copyright (C) 2006-2010                                            *)
(*                                                                        *)
(*     Sylvain Conchon                                                    *)
(*     Evelyne Contejean                                                  *)
(*     Stephane Lescuyer                                                  *)
(*     Mohamed Iguernelala                                                *)
(*     Alain Mebsout                                                      *)
(*                                                                        *)
(*     CNRS - INRIA - Universite Paris Sud                                *)
(*                                                                        *)
(*   This file is distributed under the terms of the CeCILL-C licence     *)
(*                                                                        *)
(**************************************************************************)

open Why_ptree

type env

val file : file -> ((int tdecl, int) annoted * env) list 

val split_goals : 
  ((int tdecl, int) annoted * env) list -> 
  ((int tdecl, int) annoted * env) list list

val term : env -> (Symbols.t * Ty.t) list -> Why_ptree.lexpr -> 
  (int tterm, int) annoted

val new_id : unit -> int
